smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver

# ``smartcard`.`wx`.`CardAndReaderTreePanel`.`CardAndReaderTreePanel`.`_CardObserver``

class documentation

`class _CardObserver(CardObserver):`

View In Hierarchy

Inner CardObserver. Gets notified of card insertion removal by the CardMonitor.

Method | `__init__` | Undocumented
Method | `update` | CardObserver callback that is notified when cards are added or removed.
Instance Variable | `cardtreectrl` | Undocumented

def __init__(self, cardtreectrl):
overrides `smartcard.CardMonitoring.CardObserver.__init__`

Undocumented

def update(self, observable, handlers):
overrides `smartcard.CardMonitoring.CardObserver.update`

CardObserver callback that is notified when cards are added or removed.

cardtreectrl =

Undocumented